Documentation
¶
Overview ¶
Package yaml provides the ability to work with glide.yaml files.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Config ¶
type Config struct {
Parent *Config `yaml:"-"`
Name string `yaml:"package"`
Imports Dependencies `yaml:"import"`
DevImports Dependencies `yaml:"devimport,omitempty"`
}
Config is the top-level configuration object.
func (*Config) HasDependency ¶
HasDependency returns true if the given name is listed as an import or dev import.
func (*Config) HasRecursiveDependency ¶
HasRecursiveDependency returns true if this config or one of it's parents has this dependency
type Dependencies ¶
type Dependencies []*Dependency
Dependencies is a collection of Dependency
func (Dependencies) Clone ¶
func (d Dependencies) Clone() Dependencies
func (Dependencies) DeDupe ¶
func (d Dependencies) DeDupe() (Dependencies, error)
DeDupe cleans up duplicates on a list of dependencies.
func (Dependencies) Get ¶
func (d Dependencies) Get(name string) *Dependency
Get a dependency by name
type Dependency ¶
type Dependency struct {
Name string `yaml:"package"`
Reference string `yaml:"version,omitempty"`
Ref string `yaml:"ref,omitempty"`
Pin string `yaml:"pin,omitempty"`
Repository string `yaml:"repo,omitempty"`
VcsType string `yaml:"vcs,omitempty"`
Subpackages []string `yaml:"subpackages,omitempty"`
Arch []string `yaml:"arch,omitempty"`
Os []string `yaml:"os,omitempty"`
UpdateAsVendored bool `yaml:"-"`
}
Dependency describes a package that the present package depends upon.
func (*Dependency) Clone ¶
func (d *Dependency) Clone() *Dependency
Click to show internal directories.
Click to hide internal directories.